Skip to contents

Sets up or connects to a conda Python environment for use with DOtools. If no environment path is provided, it will create one at ~/.venv/DOtools and install required Python packages: scvi-tools, celltypist, and scanpro.

Usage

DO.PyEnv(conda_path = NULL)

Arguments

conda_path

character string specifying the path to an existing or new conda environment.

Value

None

Examples

# Creates DOtools environment at ~/.venv/DOtools if it doesn't exist
DO.PyEnv()
#> 2026-08-26 10:01:38 - Creating conda environment for DOtools
#> 2026-08-26 10:03:57 - Python packages ready for DOtools!

# Use an existing conda environment at a custom location
# DO.PyEnv(conda_path = "~/miniconda3/envs/my_dotools_env")