DOtools: A Toolkit for scRNA Data Analysis
DOtools.RdThe `DOtools` package provides a set of functions for advanced data processing, visualisation, and statistical analysis in Seurat objects. It includes functions for cell-type prediction, reclustering, creating polished UMAP plots, subsetting Seurat objects, and various statistical analyses like Wilcoxon tests and SEM graphs.
Details
This package includes the following functions:
DO.BoxPlot: A function for creating box plots with Wilcoxon test results.DO.CellTypist: A function for running CellTypist on Seurat and SCE objects to predict cell types.DO.DietSCE: A function for diet-based analysis of Seurat and SCE objects.DO.Dotplot: A function for creating dot plots for visualizing gene expression.DO.FullRecluster: A function for fine-grained reclustering of Seurat and SCE objects.DO.BarplotClustert: A function for generating mean and SEM graphs for cluster-based analysis with t-tests.DO.Barplot: A function for generating mean and SEM graphs with a statistical test indicating significance.DO.Subset: A function for subsetting Seurat and SCE objects based on metadata.DO.UMAP: A function for creating polished UMAP plots using either DimPlot or FeaturePlot.DO.VlnPlot: A function for generating violin plots with Wilcoxon test results.DO.CellComposition: A function for visualizing and statistically analyzing cell-type composition changes across conditions using the Scanpro Python package, with support for bootstrapping, proportion plots, and customizable output.DO.Import: A function for building a merged Seurat and SCE object from 10x software output, or directly from provided tables.DO.Integration: A function for integrating SCE objects and Seurat objects with the provided method.DO.CellBender: A function for running CellBender in a virtual conda env with provided raw count h5 files.DO.SplitBarGSEA: A function for viusalizing GSEA result from a provided df from e.g. metascapeDO.scVI: A function for running the scVI Integration implemented in scvi-tools.DO.TransferLabel: A function for transfering annotation from a subseted object to the original seurat and SCE object.DO.PyEnv: A function for creating a conda envrionment holding all python packages needed for some functions.DO.Correlation: A function for creating a correlation plot between provided samples in the category specified.DO.Heatmap: A function for generating Heat maps on gene expression data.DO.HeatmapFC: A function for generating Heat maps showing foldchanges in expression between specified conditions.DO.MultiDGE: A function for calculating DEGs on a single cell and speudo bulk level.DO.EvalIntegration: A function for calculating sciB metrics on integration embeddingsdot-Do.BarcodeRanks: A function for estimating the number of expected cells and droplets.dot-QC.Vlnplot: A function for estimating the number of expected cells and droplets.dot-run_kbet: A self-contained call for running the kBET function.dot-kBet_fct: A self-contained version of the kBET algorithm.
See also
DO.BoxPlot, DO.CellTypist, DO.DietSCE, DO.Dotplot,
DO.FullRecluster, DO.BarplotClustert, DO.Barplot,
DO.Subset, DO.UMAP, DO.VlnPlot, DO.Import,DO.Integration, DO.CellBender,
DO.SplitBarGSEA, DO.scVI, DO.TransferLabel,DO.Heatmap,DO.HeatmapFC, DO.PyEnv,
DO.Correlation, DO.MultiDGE,DO.EvalIntegration, DO.TransferLabel, dot-Do.BarcodeRanks, dot-QC.Vlnplot,
dot-run_kbet, dot-kBet_fct