This function removes layers from a Seurat or SCE object's RNA assay based on a specified regular expression pattern. It is supposed to remove no longer needed layers from th object.
Examples
sce_data <-
readRDS(system.file("extdata", "sce_data.rds", package = "DOtools"))
sce_data <- DO.DietSCE(sce_data, pattern = "data")
#> 2026-01-21 13:39:45 - pattern: data
#> 2026-01-21 13:39:45 - Object has no layers, pattern does not need to be removed from layers.